'use strict';

var isHtmlSelector = function isHtmlSelector() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/^html/);
};

var isRootSelector = function isRootSelector() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/:root/);
};

var getDirRule = function getDirRule(rule, dir) {
    var next = rule.next();
    var selector = addDirToSelectors(rule.selector, dir);

    if (next && next.selector === selector) {
        return next;
    } else {
        return rule.cloneAfter({ selector: selector }).removeAll();
    }
};

var addDirToSelectors = function addDirToSelectors(selectors, dir) {
    var prefix = void 0;

    switch (dir) {
        case 'ltr':
        case 'rtl':
            prefix = '[dir="' + dir + '"]';
            break;
        default:
            prefix = '[dir]';
    }

    selectors = selectors.split(/\s*,\s*/).map(function (selector) {
        if (isHtmlSelector(selector)) {
            selector = selector.replace(/html/ig, 'html' + prefix);
        } else if (isRootSelector(selector)) {
            selector = selector.replace(/:root/ig, prefix + ':root');
        } else {
            selector = 'html' + prefix + ' ' + selector;
        }
        return selector;
    }).join(', ');

    return selectors;
};

module.exports = {
    isHtmlSelector: isHtmlSelector,
    isRootSelector: isRootSelector,
    getDirRule: getDirRule,
    addDirToSelectors: addDirToSelectors
};